@@ -64,9 +64,13 @@ if __name__ == "__main__":
         #var.set_value(ua.Variant([23], ua.VariantType.Int64)) #set node value using explicit data type
         #var.set_value(3.9) # set node value using implicit data type
 
+        # gettting our namespace idx
+        uri = "http://examples.freeopcua.github.io"
+        idx = client.get_namespace_index(uri)
+
         # Now getting a variable node using its browse path
-        myvar = root.get_child(["0:Objects", "2:MyObject", "2:MyVariable"])
-        obj = root.get_child(["0:Objects", "2:MyObject"])
+        myvar = root.get_child(["0:Objects", "{}:MyObject".format(idx), "{}:MyVariable".format(idx)])
+        obj = root.get_child(["0:Objects", "{}:MyObject".format(idx)])
         print("myvar is: ", myvar)
 
         # subscribing to a variable node
@@ -81,7 +85,7 @@ if __name__ == "__main__":
         # sub.delete()
 
         # calling a method on server
-        res = obj.call_method("2:multiply", 3, "klk")
+        res = obj.call_method("{}:multiply".format(idx), 3, "klk")
         print("method result is: ", res)
 
         embed()
