@@ -6,7 +6,7 @@ import logging
 import socket
 import errno
 from threading import Thread, Lock
-from concurrent.futures import Future
+from concurrent.futures import Future, CancelledError
 from functools import partial
 
 from opcua import ua
@@ -63,6 +63,11 @@ class UASocketClient(object):
             if callback:
                 future.add_done_callback(callback)
             self._callbackmap[self._request_id] = future
+
+            # Change to the new security token if the connection has been renewed.
+            if self._connection.next_security_token.TokenId != 0:
+                self._connection.revolve_tokens()
+
             msg = self._connection.message_to_binary(binreq, message_type=message_type, request_id=self._request_id)
             self._socket.write(msg)
         return future
@@ -96,9 +101,11 @@ class UASocketClient(object):
                 self._receive()
             except ua.utils.SocketClosedException:
                 self.logger.info("Socket has closed connection")
+                self._connection.close()
                 break
             except UaError:
                 self.logger.exception("Protocol Error")
+        self._cancel_all_callbacks()
         self.logger.info("Thread ended")
 
     def _receive(self):
@@ -125,6 +132,12 @@ class UASocketClient(object):
                 )
         future.set_result(body)
 
+    def _cancel_all_callbacks(self):
+        for request_id, fut in self._callbackmap.items():
+            self.logger.info("Cancelling request {:d}".format(request_id))
+            fut.cancel()
+        self._callbackmap.clear()
+
     def _create_request_header(self, timeout=1000):
         hdr = ua.RequestHeader()
         hdr.AuthenticationToken = self.authentication_token
@@ -161,7 +174,7 @@ class UASocketClient(object):
         self.logger.info("Socket closed, waiting for receiver thread to terminate...")
         if self._thread and self._thread.is_alive():
             self._thread.join()
-        self._callbackmap.clear()
+        self._cancel_all_callbacks()
         self.logger.info("Done closing socket: Receiving thread terminated, socket disconnected")
 
     def send_hello(self, url, max_messagesize=0, max_chunkcount=0):
@@ -183,11 +196,9 @@ class UASocketClient(object):
         request.Parameters = params
         future = self._send_request(request, message_type=ua.MessageType.SecureOpen)
 
-        # FIXME: we have a race condition here
-        # we can get a packet with the new token id before we reach to store it..
         response = struct_from_binary(ua.OpenSecureChannelResponse, future.result(self.timeout))
         response.ResponseHeader.ServiceResult.check()
-        self._connection.set_channel(response.Parameters)
+        self._connection.set_channel(response.Parameters, params.RequestType, params.ClientNonce)
         return response.Parameters
 
     def close_secure_channel(self):
@@ -409,24 +420,30 @@ class UaClient(object):
         response.ResponseHeader.ServiceResult.check()
         return response.Results
 
-    def create_subscription(self, params, callback):
+    def create_subscription(self, params, publish_callback, ready_callback=None):
         self.logger.info("create_subscription")
         request = ua.CreateSubscriptionRequest()
         request.Parameters = params
         resp_fut = Future()
-        mycallbak = partial(self._create_subscription_callback, callback, resp_fut)
+        mycallbak = partial(self._create_subscription_callback, publish_callback, ready_callback, resp_fut)
         self._uasocket.send_request(request, mycallbak)
         return resp_fut.result(self._timeout)
 
-    def _create_subscription_callback(self, pub_callback, resp_fut, data_fut):
+    def _create_subscription_callback(self, pub_callback, ready_callback, resp_fut, data_fut):
         self.logger.info("_create_subscription_callback")
         data = data_fut.result()
         response = struct_from_binary(ua.CreateSubscriptionResponse, data)
         self.logger.debug(response)
         response.ResponseHeader.ServiceResult.check()
+        if ready_callback:
+            ready_callback(response)
         self._publishcallbacks[response.Parameters.SubscriptionId] = pub_callback
         resp_fut.set_result(response.Parameters)
 
+    def registered_subscriptions(self):
+        """Get all subscriptions we know about"""
+        return [cb.__self__ for cb in self._publishcallbacks.values()]
+
     def delete_subscriptions(self, subscriptionids):
         self.logger.info("delete_subscription")
         request = ua.DeleteSubscriptionsRequest()
@@ -456,7 +473,10 @@ class UaClient(object):
 
     def _call_publish_callback(self, future):
         self.logger.info("call_publish_callback")
-        data = future.result()
+        try:
+            data = future.result()
+        except CancelledError:  # we are cancelled, we just return
+            return
 
         # check if answer looks ok
         try:
@@ -594,3 +614,55 @@ class UaClient(object):
         self.logger.debug(response)
         response.ResponseHeader.ServiceResult.check()
         return response.Results
+
+    def register_nodes(self, nodes):
+        self.logger.info("register_nodes")
+        request = ua.RegisterNodesRequest()
+        request.Parameters.NodesToRegister = nodes
+        data = self._uasocket.send_request(request)
+        response = struct_from_binary(ua.RegisterNodesResponse, data)
+        self.logger.debug(response)
+        response.ResponseHeader.ServiceResult.check()
+        return response.Parameters.RegisteredNodeIds
+
+    def unregister_nodes(self, nodes):
+        self.logger.info("unregister_nodes")
+        request = ua.UnregisterNodesRequest()
+        request.Parameters.NodesToUnregister = nodes
+        data = self._uasocket.send_request(request)
+        response = struct_from_binary(ua.UnregisterNodesResponse, data)
+        self.logger.debug(response)
+        response.ResponseHeader.ServiceResult.check()
+        # nothing to return for this service
+
+    def get_attributes(self, nodes, attr):
+        self.logger.info("get_attribute")
+        request = ua.ReadRequest()
+        for node in nodes:
+            rv = ua.ReadValueId()
+            rv.NodeId = node
+            rv.AttributeId = attr
+            request.Parameters.NodesToRead.append(rv)
+        data = self._uasocket.send_request(request)
+        response = struct_from_binary(ua.ReadResponse, data)
+        response.ResponseHeader.ServiceResult.check()
+        return response.Results
+
+    def set_attributes(self, nodeids, datavalues, attributeid=ua.AttributeIds.Value):
+        """
+        Set an attribute of multiple nodes
+        datavalue is a ua.DataValue object
+        """
+        self.logger.info("set_attributes of several nodes")
+        request = ua.WriteRequest()
+        for idx, nodeid in enumerate(nodeids):
+            attr = ua.WriteValue()
+            attr.NodeId = nodeid
+            attr.AttributeId = attributeid
+            attr.Value = datavalues[idx]
+            request.Parameters.NodesToWrite.append(attr)
+        data = self._uasocket.send_request(request)
+        response = struct_from_binary(ua.WriteResponse, data)
+        response.ResponseHeader.ServiceResult.check()
+        return response.Results
+
