@@ -11,12 +11,29 @@ from opcua import ua
 from opcua.ua.uaerrors import UaError
 
 
-def val_to_string(val):
+def value_to_datavalue(val, varianttype=None):
+    """
+    convert anyting to a DataValue using varianttype
+    """
+    datavalue = None
+    if isinstance(val, ua.DataValue):
+        datavalue = val
+    elif isinstance(val, ua.Variant):
+        datavalue = ua.DataValue(val)
+        datavalue.SourceTimestamp = datetime.utcnow()
+    else:
+        datavalue = ua.DataValue(ua.Variant(val, varianttype))
+        datavalue.SourceTimestamp = datetime.utcnow()
+    return datavalue
+
+
+def val_to_string(val, truncate=False):
     """
     convert a python object or python-opcua object to a string
     which should be easy to understand for human
     easy to modify, and not too hard to parse back ....not easy
     meant for UI or command lines
+    if truncate is true then huge strings or bytes are tuncated
 
     """
     if isinstance(val, (list, tuple)):
@@ -36,9 +53,13 @@ def val_to_string(val):
     elif isinstance(val, ua.XmlElement):
         val = val.Value
     elif isinstance(val, str):
-        pass
+        if truncate and len(val) > 100:
+            val = val[:10] + "...." + val[-10:]
     elif isinstance(val, bytes):
-        val = str(val)
+        if truncate and len(val) > 100:
+            val = val[:10].decode("utf-8", errors="replace") + "...." + val[-10:].decode("utf-8", errors="replace")
+        else:
+            val = val.decode("utf-8", errors="replace")
     elif isinstance(val, datetime):
         val = val.isoformat()
     elif isinstance(val, (int, float)):
@@ -91,7 +112,7 @@ def string_to_val(string, vtype):
     elif vtype == ua.VariantType.String:
         val = string
     elif vtype == ua.VariantType.ByteString:
-        val = string.encode("utf-8")
+        val = string.encode()
     elif vtype in (ua.VariantType.NodeId, ua.VariantType.ExpandedNodeId):
         val = ua.NodeId.from_string(string)
     elif vtype == ua.VariantType.QualifiedName:
@@ -144,7 +165,7 @@ def get_node_supertypes(node, includeitself=False, skipbase=True):
     :param node: can be a ua.Node or ua.NodeId
     :param includeitself: include also node to the list
     :param skipbase don't include the toplevel one
-    :returns list of ua.Node, top parent first 
+    :returns list of ua.Node, top parent first
     """
     parents = []
     if includeitself:
@@ -187,7 +208,7 @@ def is_child_present(node, browsename):
     return if a browsename is present a child from the provide node
     :param node: node wherein to find the browsename
     :param browsename: browsename to search
-    :returns returne True if the browsename is present else False 
+    :returns returne True if the browsename is present else False
     """
     child_descs = node.get_children_descriptions()
     for child_desc in child_descs:
@@ -215,7 +236,7 @@ def get_base_data_type(datatype):
     Looks up the base datatype of the provided datatype Node
     The base datatype is either:
     A primitive type (ns=0, i<=21) or a complex one (ns=0 i>21 and i<=30) like Enum and Struct.
-    
+
     Args:
         datatype: NodeId of a datype of a variable
     Returns:
@@ -231,7 +252,7 @@ def get_base_data_type(datatype):
 
 def get_nodes_of_namespace(server, namespaces=None):
     """
-    Get the nodes of one or more namespaces .      
+    Get the nodes of one or more namespaces .
     Args:
         server: opc ua server to use
         namespaces: list of string uri or int indexes of the namespace to export
@@ -265,3 +286,12 @@ def get_default_value(uatype):
         return getattr(ua, uatype)()
 
 
+def data_type_to_string(dtype):
+    # we could just display browse name of node but it requires a query
+    if dtype.NamespaceIndex == 0 and dtype.Identifier in ua.ObjectIdNames:
+        string = ua.ObjectIdNames[dtype.Identifier]
+    else:
+        string = dtype.to_string()
+    return string
+
+
