@@ -78,8 +78,8 @@ class MonitoredItemService(object):
 
     def trigger_datachange(self, handle, nodeid, attr):
         self.logger.debug("triggering datachange for handle %s, nodeid %s, and attribute %s", handle, nodeid, attr)
-        variant = self.aspace.get_attribute_value(nodeid, attr)
-        self.datachange_callback(handle, variant)
+        datavalue = self.aspace.get_attribute_value(nodeid, attr)
+        self.datachange_callback(handle, datavalue)
 
     def _modify_monitored_item(self, params):
         with self._lock:
@@ -99,7 +99,6 @@ class MonitoredItemService(object):
     def _commit_monitored_item(self, result, mdata):
         if result.StatusCode.is_good():
             self._monitored_items[result.MonitoredItemId] = mdata
-            self._monitored_item_counter += 1
 
     def _make_monitored_item_common(self, params):
         result = ua.MonitoredItemCreateResult()
@@ -370,10 +369,10 @@ class InternalSubscription(object):
     def republish(self, nb):
         self.logger.info("re-publish request for ack %s in subscription %s", nb, self)
         with self._lock:
-            notificationMessage = self._not_acknowledged_results.pop(nb, None)
-            if notificationMessage:
+            result = self._not_acknowledged_results.pop(nb, None)
+            if result:
                 self.logger.info("re-publishing ack %s in subscription %s", nb, self)
-                return notificationMessage
+                return result.NotificationMessage
             else:
                 self.logger.info("Error request to re-published non existing ack %s in subscription %s", nb, self)
                 return ua.NotificationMessage()
