@@ -15,8 +15,8 @@ class Hello(uatypes.FrozenClass):
 
     def __init__(self):
         self.ProtocolVersion = 0
-        self.ReceiveBufferSize = 65536
-        self.SendBufferSize = 65536
+        self.ReceiveBufferSize = 2**32 - 1
+        self.SendBufferSize = 2**32 - 1
         self.MaxMessageSize = 0 # No limits
         self.MaxChunkCount = 0 # No limits
         self.EndpointUrl = ""
