@@ -24,10 +24,10 @@ class HistoryCommon(object):
     @classmethod
     def start_server_and_client(cls):
         cls.srv = Server()
-        cls.srv.set_endpoint('opc.tcp://localhost:{0:d}'.format(port_num1))
+        cls.srv.set_endpoint('opc.tcp://127.0.0.1:{0:d}'.format(port_num1))
         cls.srv.start()
 
-        cls.clt = Client('opc.tcp://localhost:{0:d}'.format(port_num1))
+        cls.clt = Client('opc.tcp://127.0.0.1:{0:d}'.format(port_num1))
         cls.clt.connect()
 
     @classmethod
@@ -260,7 +260,7 @@ class TestHistoryLimitsCommon(unittest.TestCase):
 
     def addValue(self, age):
         value = ua.DataValue()
-        value.ServerTimestamp = datetime.utcnow() - timedelta(hours = age)
+        value.SourceTimestamp = datetime.utcnow() - timedelta(hours = age)
         self.history.save_node_value(self.id, value)
 
     def test_count_limit(self):
