@@ -2,12 +2,12 @@ import unittest
 import os
 import shelve
 import time
-from enum import Enum, EnumMeta
+from enum import EnumMeta
 
 from tests_common import CommonTests, add_server_methods
 from tests_xml import XmlTests
 from tests_subscriptions import SubscriptionTests
-from datetime import timedelta, datetime
+from datetime import timedelta
 from tempfile import NamedTemporaryFile
 
 import opcua
@@ -53,7 +53,7 @@ class TestServer(unittest.TestCase, CommonTests, SubscriptionTests, XmlTests):
         try:
             servers = client.find_servers()
             new_app_uri = "urn:freeopcua:python:server:test_discovery"
-            self.srv.application_uri = new_app_uri
+            self.srv.set_application_uri(new_app_uri)
             with RegistrationService() as regService:
                 regService.register_to_discovery(self.srv, self.discovery.endpoint.geturl(), period=0)
                 time.sleep(0.1)  # let server register registration
@@ -73,11 +73,11 @@ class TestServer(unittest.TestCase, CommonTests, SubscriptionTests, XmlTests):
             with RegistrationService() as regService1, RegistrationService() as regService2:
                 # Register to server with uri1
                 new_app_uri1 = "urn:freeopcua:python:server:test_discovery1"
-                self.srv.application_uri = new_app_uri1
+                self.srv.set_application_uri(new_app_uri1)
                 regService1.register_to_discovery(self.srv, self.discovery.endpoint.geturl(), period=0)
                 # Register to server with uri2
                 new_app_uri2 = "urn:freeopcua:python:test_discovery2"
-                self.srv.application_uri = new_app_uri2
+                self.srv.set_application_uri(new_app_uri2)
                 regService2.register_to_discovery(self.srv, self.discovery.endpoint.geturl(), period=0)
                 # Check for 2 registrations
                 time.sleep(0.1)  # let server register registration
@@ -327,7 +327,7 @@ class TestServer(unittest.TestCase, CommonTests, SubscriptionTests, XmlTests):
     # For the custom events all posibilites are tested. For other custom types only one test case is done since they are using the same code
     def test_create_custom_data_type_ObjectId(self):
         type = self.opc.create_custom_data_type(2, 'MyDataType', ua.ObjectIds.BaseDataType, [('PropertyNum', ua.VariantType.Int32), ('PropertyString', ua.VariantType.String)])
-        check_custom_type(self, type, ua.ObjectIds.BaseDataType)
+        check_custom_type(self, type, ua.ObjectIds.BaseDataType, ua.NodeClass.DataType)
 
     def test_create_custom_event_type_ObjectId(self):
         type = self.opc.create_custom_event_type(2, 'MyEvent', ua.ObjectIds.BaseEventType, [('PropertyNum', ua.VariantType.Int32), ('PropertyString', ua.VariantType.String)])
@@ -571,12 +571,16 @@ def check_custom_event(test, ev, etype):
     test.assertEqual(ev.Severity, 1)
 
 
-def check_custom_type(test, type, base_type):
+def check_custom_type(test, type, base_type, node_class=None):
     base = opcua.Node(test.opc.iserver.isession, ua.NodeId(base_type))
     test.assertTrue(type in base.get_children())
     nodes = type.get_referenced_nodes(refs=ua.ObjectIds.HasSubtype, direction=ua.BrowseDirection.Inverse, includesubtypes=True)
     test.assertEqual(base, nodes[0])
     properties = type.get_properties()
+
+    if node_class:
+        test.assertEqual(node_class, type.get_node_class())
+
     test.assertIsNot(properties, None)
     test.assertEqual(len(properties), 2)
     test.assertTrue(type.get_child("2:PropertyNum") in properties)
