@@ -590,11 +590,11 @@ class TestUnit(unittest.TestCase):
             self.assertTrue(len(chunk.to_binary()) <= 28)
 
     def test_null(self):
-        n = ua.NodeId(b'000000', 0, nodeidtype=ua.NodeIdType.Guid)
+        n = ua.NodeId(uuid.UUID('00000000-0000-0000-0000-000000000000'), 0, nodeidtype=ua.NodeIdType.Guid)
         self.assertTrue(n.is_null())
         self.assertTrue(n.has_null_identifier())
 
-        n = ua.NodeId(b'000000', 1, nodeidtype=ua.NodeIdType.Guid)
+        n = ua.NodeId(uuid.UUID('00000000-0000-0000-0000-000000000000'), 1, nodeidtype=ua.NodeIdType.Guid)
         self.assertFalse(n.is_null())
         self.assertTrue(n.has_null_identifier())
 
